@@ -24,6 +24,7 @@
 #include <kio/netaccess.h>
 #include <KMessageBox>
 #include <KPasswordDialog>
+#include <KPushButton>
 #include <knewpassworddialog.h>
 #include <KLocale>
 #include <KProcess>
@@ -423,8 +424,10 @@ int KgpgInterface::sendPassphrase(const QString &text, KProcess *process, const
 	QPointer<KProcess> gpgprocess = process;
 	QByteArray passphrase;
 	int code;
+
 	if (isnew) {
 		QPointer<KNewPasswordDialog> dlg = new KNewPasswordDialog(widget);
+		QObject::connect(process, SIGNAL(processExited()), dlg->button(KDialog::Cancel), SLOT(click()));
 		dlg->setPrompt(text);
 		dlg->setAllowEmptyPasswords(false);
 		code = dlg->exec();
@@ -433,6 +436,7 @@ int KgpgInterface::sendPassphrase(const QString &text, KProcess *process, const
 		delete dlg;
 	} else {
 		QPointer<KPasswordDialog> dlg = new KPasswordDialog(widget);
+		QObject::connect(process, SIGNAL(processExited()), dlg->button(KDialog::Cancel), SLOT(click()));
 		dlg->setPrompt(text);
 		code = dlg->exec();
 		if (!dlg.isNull())
@@ -517,7 +521,7 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 			m_publickey.setTrust(Convert::toTrust(lsp.at(1)));
 			m_publickey.setSize(lsp.at(2).toUInt());
 			m_publickey.setAlgorithm(Convert::toAlgo(lsp.at(3).toInt()));
-			m_publickey.setFingerprint(lsp.at(4));
+			m_publickey.setKeyId(lsp.at(4));
 			m_publickey.setCreation(QDateTime::fromTime_t(lsp.at(5).toUInt()));
 			m_publickey.setOwnerTrust(Convert::toOwnerTrust(lsp.at(8)));
 
@@ -685,7 +689,7 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 			m_secretkey.setTrust(Convert::toTrust(lsp.at(1)));
 			m_secretkey.setSize(lsp.at(2).toUInt());
 			m_secretkey.setAlgorithm(Convert::toAlgo(lsp.at(3).toInt()));
-			m_secretkey.setFingerprint(lsp.at(4));
+			m_secretkey.setKeyId(lsp.at(4));
 			m_secretkey.setCreation(QDateTime::fromTime_t(lsp.at(5).toUInt()));
 			m_secretkey.setSecret(true);
 
